@@ -2,14 +2,12 @@ from guillotina import task_vars
 from guillotina.component import get_adapter
 from guillotina.component import get_utility
 from guillotina.component import globalregistry as gr
-from guillotina.db.uid import get_short_uid
 from guillotina.event import notify
 from guillotina.events import ObjectRemovedEvent
 from guillotina.interfaces import ICatalogUtility
 from guillotina.tests.utils import create_content
 from guillotina_elasticsearch.events import IIndexProgress
 from guillotina_elasticsearch.events import IndexProgress
-from guillotina_elasticsearch.interfaces import DOC_TYPE
 from guillotina_elasticsearch.interfaces import IIndexManager
 from guillotina_elasticsearch.migration import Migrator
 from guillotina_elasticsearch.reindex import Reindexer
@@ -17,8 +15,8 @@ from guillotina_elasticsearch.tests.utils import add_content
 from guillotina_elasticsearch.tests.utils import run_with_retries
 from guillotina_elasticsearch.tests.utils import setup_txn_on_container
 
-import aioelasticsearch
 import asyncio
+import elasticsearch
 import json
 import pytest
 import random
@@ -96,19 +94,15 @@ async def test_removes_orphans(es_requester):
         im = get_adapter(container, IIndexManager)
         index_name = await im.get_index_name()  # alias
 
-        doc = await search.get_connection().get(
-            index=index_name, doc_type=DOC_TYPE, id="foobar"
-        )
+        doc = await search.get_connection().get(index=index_name, id="foobar")
         assert doc["found"]
 
         migrator = Migrator(search, container, force=True)
         await migrator.run_migration()
 
         async def _test():
-            with pytest.raises(aioelasticsearch.exceptions.NotFoundError):
-                await search.get_connection().get(
-                    index=index_name, doc_type=DOC_TYPE, id="foobar"
-                )
+            with pytest.raises(elasticsearch.exceptions.NotFoundError):
+                await search.get_connection().get(index=index_name, id="foobar")
 
             assert len(migrator.orphaned) == 1
             assert migrator.orphaned[0] == "foobar"
@@ -200,9 +194,7 @@ async def test_updates_index_data(es_requester):
         await asyncio.sleep(1)
         await search.refresh(container, new_index_name)
         await asyncio.sleep(1)
-        doc = await search.get_connection().get(
-            index=new_index_name, doc_type=DOC_TYPE, id=ob.__uuid__
-        )
+        doc = await search.get_connection().get(index=new_index_name, id=ob.__uuid__)
         assert doc["_source"]["title"] == "foobar-new"
 
 
@@ -409,7 +401,7 @@ async def test_search_works_on_updated_docs_during_migration_when_missing(
             )
             assert result1 is not None
             assert result1["_source"]["title"] == "Foobar2"
-            with pytest.raises(aioelasticsearch.exceptions.NotFoundError):
+            with pytest.raises(elasticsearch.exceptions.NotFoundError):
                 await search.get_connection().get(
                     index=next_index_name, doc_type="_all", id=resp["@uid"]
                 )
@@ -475,80 +467,13 @@ async def test_delete_in_both_during_migration(es_requester):
         await requester("DELETE", "/db/guillotina/foobar")
 
         async def _test():
-            with pytest.raises(aioelasticsearch.exceptions.NotFoundError):
+            with pytest.raises(elasticsearch.exceptions.NotFoundError):
                 await search.get_connection().get(
                     index=next_index_name, doc_type="_all", id=resp["@uid"]
                 )
-            with pytest.raises(aioelasticsearch.exceptions.NotFoundError):
+            with pytest.raises(elasticsearch.exceptions.NotFoundError):
                 await search.get_connection().get(
                     index=index_name, doc_type="_all", id=resp["@uid"]
                 )
 
         await run_with_retries(_test, requester)
-
-
-async def test_migrate_content_index_works(es_requester):
-    async with es_requester as requester:
-        add_count = await add_content(requester)
-        cresp, _ = await requester(
-            "POST",
-            "/db/guillotina/",
-            data=json.dumps({"@type": "UniqueIndexContent", "id": "foobar"}),
-        )
-        await requester(
-            "POST",
-            "/db/guillotina/foobar",
-            data=json.dumps({"@type": "IndexItemContent"}),
-        )
-
-        container, request, txn, tm = await setup_txn_on_container(requester)
-
-        search = get_utility(ICatalogUtility)
-        await search.refresh(container)
-        await asyncio.sleep(3)
-
-        assert (add_count + 1) == await search.get_doc_count(
-            container, "guillotina-db-guillotina_1"
-        )
-        assert (
-            await search.get_doc_count(
-                container,
-                "1_guillotina-db-guillotina__uniqueindexcontent-{}".format(  # noqa
-                    get_short_uid(cresp["@uid"])
-                ),
-            )
-            == 1
-        )
-
-        migrator = Migrator(search, container, force=True)
-        await migrator.run_migration()
-
-        assert await search.get_connection().indices.exists(
-            "guillotina-db-guillotina_2"
-        )
-        assert not await search.get_connection().indices.exists(
-            "guillotina-db-guillotina_1"
-        )
-        assert await search.get_connection().indices.exists(
-            "2_guillotina-db-guillotina__uniqueindexcontent-{}".format(
-                get_short_uid(cresp["@uid"])
-            )
-        )
-        assert not await search.get_connection().indices.exists(
-            "1_guillotina-db-guillotina__uniqueindexcontent-{}".format(
-                get_short_uid(cresp["@uid"])
-            )
-        )
-
-        assert (add_count + 1) == await search.get_doc_count(
-            container, "guillotina-db-guillotina_2"
-        )
-        assert (
-            await search.get_doc_count(
-                container,
-                "2_guillotina-db-guillotina__uniqueindexcontent-{}".format(  # noqa
-                    get_short_uid(cresp["@uid"])
-                ),
-            )
-            == 1
-        )
